OC.L10N.register(
    "photos",
    {
    "Public link" : "Publiskā saite",
    "Photos" : "Bildes",
    "Videos" : "Video",
    "Albums" : "Albumi",
    "Folders" : "Mapes",
    "Favorites" : "Favorīti",
    "Shared with you" : "Koplietots ar tevi",
    "Tags" : "Birkas",
    "Back" : "Atpakaļ",
    "Save" : "Saglabāt",
    "Create album" : "Izveidot albumu",
    "Shared by" : "Koplietoja",
    "Group" : "Grupa",
    "Copy the public link" : "Kopējiet publisko saiti",
    "Public link copied!" : "Publiskā saite nokopēta!",
    "Copy public link" : "Kopējiet publisko saiti",
    "Delete the public link" : "Dzēst publisko saiti",
    "Share via public link" : "Kopīgojiet, izmantojot publisko saiti",
    "An error occurred" : "Gadījās kļūda",
    "Favorite" : "Favorīts",
    "Go back" : "Atpakaļ",
    "Dates" : "Datumi",
    "Home" : "Sākums",
    "View" : "Skats",
    "Remove from favorites" : "Noņemt no izlases",
    "Add" : "Pievienot",
    "Details" : "Detaļas",
    "Invalid location selected" : "Ir izvēlēta nederīga atrašanās vieta "
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
